@@ -1,17 +1,17 @@
 /**************************************************************
- *** RHmm version 1.4.2                                     
+ *** RHmm version 1.4.3                                     
  ***                                                         
  *** File: cOTError.cpp 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/11/26                                     
+ *** Date: 2010/12/01                                     
  ***                                                         
  **************************************************************/
 
 #include "cOTError.h"
 
-cOTError::cOTError(char *theMess)
+cOTError::cOTError(const char *theMess)
 {
         if (theMess != (char *)NULL) 
                 std::cout << theMess << std::endl ;
